@@ -8,12 +8,15 @@ except ImportError:
     import importlib_metadata
 
 from ._raysql_internal import (
-    Context
+    Context,
+    QueryStage,
+    serialize_execution_plan,
+    deserialize_execution_plan
 )
 
 __version__ = importlib_metadata.version(__name__)
 
 __all__ = [
     "Context",
-    "Worker"
+    "Worker",
 ]
